self.__precacheManifest = [
  {
    "revision": "90647b71b9e2ed50c681",
    "url": "./static/js/main.a5431368.chunk.js"
  },
  {
    "revision": "8c97409f0ee389fe75da",
    "url": "./static/js/runtime~main.d653cc00.js"
  },
  {
    "revision": "49bb57c02bf4a7f3d186",
    "url": "./static/js/2.4f5e4631.chunk.js"
  },
  {
    "revision": "b5bffcc742230c77c313759b940e364e",
    "url": "./index.html"
  }
];