(window.webpackJsonp=window.webpackJsonp||[]).push([[0],{15:function(e,t,n){e.exports=n(25)},25:function(e,t,n){"use strict";n.r(t);var o=n(6),a=n.n(o),r=n(13),i=n.n(r),c=n(0),l=n(4),u=n(2),d=n(1),p=n(3),s=n(8),m=n(9),h=function(e){function t(){var e,n;Object(c.a)(this,t);for(var o=arguments.length,r=new Array(o),i=0;i<o;i++)r[i]=arguments[i];return(n=Object(u.a)(this,(e=Object(d.a)(t)).call.apply(e,[this].concat(r)))).render=function(){var e=n.props.args,t=e.title,o=e.text,r=e.image,i=n.props.theme;if(!i)return a.a.createElement("div",null,"Theme is undefined, please check streamlit version.");var c=m.a.div({display:"flex",cursor:"pointer",fontFamily:"".concat(i.font,", 'Segoe UI', 'Roboto', sans-serif"),height:"".concat(250,"px"),borderRadius:"20px",overflow:"hidden",backgroundImage:"url(".concat(r,")"),backgroundPosition:"center",backgroundSize:"cover",backgroundRepeat:"no-repeat",backgroundColor:"#eee",boxShadow:"0px 0px 40px rgba(0, 0, 0, 0.2)",margin:"".concat(40,"px"),flexDirection:"column",justifyContent:"center",alignItems:"center",textAlign:"center",color:i.textColor,width:"".concat(300,"px"),position:"relative"}),l=m.a.div({height:330,width:380,margin:"auto"}),u=m.a.h2({color:"white",zIndex:"2",fontSize:"2em",fontWeight:"bolder"}),d=m.a.p({color:"white",fontWeight:"bolder",zIndex:"2",fontSize:"1em"}),p=m.a.div({backgroundColor:"rgba(0, 0, 0, 0.5)",height:"100%",width:"100%",position:"absolute",top:"0",left:"0",zIndex:"1"});return a.a.createElement(l,null,a.a.createElement(c,{onClick:n.onClick},a.a.createElement(p,null),a.a.createElement(u,null,t),a.a.createElement(d,null,o)))},n.onClick=function(){s.a.setComponentValue(!0)},n}return Object(p.a)(t,e),Object(l.a)(t,[{key:"componentDidUpdate",value:function(){s.a.setFrameHeight()}},{key:"componentDidMount",value:function(){s.a.setFrameHeight()}}]),t}(s.b),g=Object(s.c)(h);i.a.render(a.a.createElement(a.a.StrictMode,null,a.a.createElement(g,null)),document.getElementById("root"))}},[[15,1,2]]]);
//# sourceMappingURL=main.a5431368.chunk.js.map